# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceLock(object):
    """
    Resource locks prevent certain APIs from being called for the resource.
    A full lock prevents both updating and deleting the resource. A lock delete
    prevents deleting the resource.
    """

    #: A constant which can be used with the type property of a ResourceLock.
    #: This constant has a value of "FULL"
    TYPE_FULL = "FULL"

    #: A constant which can be used with the type property of a ResourceLock.
    #: This constant has a value of "DELETE"
    TYPE_DELETE = "DELETE"

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceLock object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this ResourceLock.
            Allowed values for this property are: "FULL", "DELETE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param related_resource_id:
            The value to assign to the related_resource_id property of this ResourceLock.
        :type related_resource_id: str

        :param message:
            The value to assign to the message property of this ResourceLock.
        :type message: str

        :param time_created:
            The value to assign to the time_created property of this ResourceLock.
        :type time_created: datetime

        """
        self.swagger_types = {
            'type': 'str',
            'related_resource_id': 'str',
            'message': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'type': 'type',
            'related_resource_id': 'relatedResourceId',
            'message': 'message',
            'time_created': 'timeCreated'
        }

        self._type = None
        self._related_resource_id = None
        self._message = None
        self._time_created = None

    @property
    def type(self):
        """
        **[Required]** Gets the type of this ResourceLock.
        Lock type.

        Allowed values for this property are: "FULL", "DELETE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this ResourceLock.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ResourceLock.
        Lock type.


        :param type: The type of this ResourceLock.
        :type: str
        """
        allowed_values = ["FULL", "DELETE"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def related_resource_id(self):
        """
        Gets the related_resource_id of this ResourceLock.
        The resource ID that is locking this resource. Indicates that deleting this resource removes the lock.


        :return: The related_resource_id of this ResourceLock.
        :rtype: str
        """
        return self._related_resource_id

    @related_resource_id.setter
    def related_resource_id(self, related_resource_id):
        """
        Sets the related_resource_id of this ResourceLock.
        The resource ID that is locking this resource. Indicates that deleting this resource removes the lock.


        :param related_resource_id: The related_resource_id of this ResourceLock.
        :type: str
        """
        self._related_resource_id = related_resource_id

    @property
    def message(self):
        """
        Gets the message of this ResourceLock.
        A message added by the lock creator. The message typically gives an
        indication of why the resource is locked.


        :return: The message of this ResourceLock.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ResourceLock.
        A message added by the lock creator. The message typically gives an
        indication of why the resource is locked.


        :param message: The message of this ResourceLock.
        :type: str
        """
        self._message = message

    @property
    def time_created(self):
        """
        Gets the time_created of this ResourceLock.
        Indicates when the lock was created, in the format defined by RFC 3339.


        :return: The time_created of this ResourceLock.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ResourceLock.
        Indicates when the lock was created, in the format defined by RFC 3339.


        :param time_created: The time_created of this ResourceLock.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FilterGroupMembershipDetails(object):
    """
    FilterGroupMembershipDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FilterGroupMembershipDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param principal:
            The value to assign to the principal property of this FilterGroupMembershipDetails.
        :type principal: oci.identity_data_plane.models.Principal

        :param group_ids:
            The value to assign to the group_ids property of this FilterGroupMembershipDetails.
        :type group_ids: list[str]

        """
        self.swagger_types = {
            'principal': 'Principal',
            'group_ids': 'list[str]'
        }

        self.attribute_map = {
            'principal': 'principal',
            'group_ids': 'groupIds'
        }

        self._principal = None
        self._group_ids = None

    @property
    def principal(self):
        """
        **[Required]** Gets the principal of this FilterGroupMembershipDetails.
        A resolved principal object


        :return: The principal of this FilterGroupMembershipDetails.
        :rtype: oci.identity_data_plane.models.Principal
        """
        return self._principal

    @principal.setter
    def principal(self, principal):
        """
        Sets the principal of this FilterGroupMembershipDetails.
        A resolved principal object


        :param principal: The principal of this FilterGroupMembershipDetails.
        :type: oci.identity_data_plane.models.Principal
        """
        self._principal = principal

    @property
    def group_ids(self):
        """
        **[Required]** Gets the group_ids of this FilterGroupMembershipDetails.
        An array of group or dynamic group Ids the resolved principal potentially belongs to.


        :return: The group_ids of this FilterGroupMembershipDetails.
        :rtype: list[str]
        """
        return self._group_ids

    @group_ids.setter
    def group_ids(self, group_ids):
        """
        Sets the group_ids of this FilterGroupMembershipDetails.
        An array of group or dynamic group Ids the resolved principal potentially belongs to.


        :param group_ids: The group_ids of this FilterGroupMembershipDetails.
        :type: list[str]
        """
        self._group_ids = group_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IdcsInfoDetails(object):
    """
    Information for IDCS access
    """

    def __init__(self, **kwargs):
        """
        Initializes a new IdcsInfoDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param idcs_app_location_url:
            The value to assign to the idcs_app_location_url property of this IdcsInfoDetails.
        :type idcs_app_location_url: str

        :param idcs_app_display_name:
            The value to assign to the idcs_app_display_name property of this IdcsInfoDetails.
        :type idcs_app_display_name: str

        :param idcs_app_id:
            The value to assign to the idcs_app_id property of this IdcsInfoDetails.
        :type idcs_app_id: str

        :param idcs_app_name:
            The value to assign to the idcs_app_name property of this IdcsInfoDetails.
        :type idcs_app_name: str

        :param instance_primary_audience_url:
            The value to assign to the instance_primary_audience_url property of this IdcsInfoDetails.
        :type instance_primary_audience_url: str

        """
        self.swagger_types = {
            'idcs_app_location_url': 'str',
            'idcs_app_display_name': 'str',
            'idcs_app_id': 'str',
            'idcs_app_name': 'str',
            'instance_primary_audience_url': 'str'
        }

        self.attribute_map = {
            'idcs_app_location_url': 'idcsAppLocationUrl',
            'idcs_app_display_name': 'idcsAppDisplayName',
            'idcs_app_id': 'idcsAppId',
            'idcs_app_name': 'idcsAppName',
            'instance_primary_audience_url': 'instancePrimaryAudienceUrl'
        }

        self._idcs_app_location_url = None
        self._idcs_app_display_name = None
        self._idcs_app_id = None
        self._idcs_app_name = None
        self._instance_primary_audience_url = None

    @property
    def idcs_app_location_url(self):
        """
        **[Required]** Gets the idcs_app_location_url of this IdcsInfoDetails.
        URL for the location of the IDCS Application (used by IDCS APIs)


        :return: The idcs_app_location_url of this IdcsInfoDetails.
        :rtype: str
        """
        return self._idcs_app_location_url

    @idcs_app_location_url.setter
    def idcs_app_location_url(self, idcs_app_location_url):
        """
        Sets the idcs_app_location_url of this IdcsInfoDetails.
        URL for the location of the IDCS Application (used by IDCS APIs)


        :param idcs_app_location_url: The idcs_app_location_url of this IdcsInfoDetails.
        :type: str
        """
        self._idcs_app_location_url = idcs_app_location_url

    @property
    def idcs_app_display_name(self):
        """
        **[Required]** Gets the idcs_app_display_name of this IdcsInfoDetails.
        The IDCS application display name associated with the instance


        :return: The idcs_app_display_name of this IdcsInfoDetails.
        :rtype: str
        """
        return self._idcs_app_display_name

    @idcs_app_display_name.setter
    def idcs_app_display_name(self, idcs_app_display_name):
        """
        Sets the idcs_app_display_name of this IdcsInfoDetails.
        The IDCS application display name associated with the instance


        :param idcs_app_display_name: The idcs_app_display_name of this IdcsInfoDetails.
        :type: str
        """
        self._idcs_app_display_name = idcs_app_display_name

    @property
    def idcs_app_id(self):
        """
        **[Required]** Gets the idcs_app_id of this IdcsInfoDetails.
        The IDCS application ID associated with the instance


        :return: The idcs_app_id of this IdcsInfoDetails.
        :rtype: str
        """
        return self._idcs_app_id

    @idcs_app_id.setter
    def idcs_app_id(self, idcs_app_id):
        """
        Sets the idcs_app_id of this IdcsInfoDetails.
        The IDCS application ID associated with the instance


        :param idcs_app_id: The idcs_app_id of this IdcsInfoDetails.
        :type: str
        """
        self._idcs_app_id = idcs_app_id

    @property
    def idcs_app_name(self):
        """
        **[Required]** Gets the idcs_app_name of this IdcsInfoDetails.
        The IDCS application name associated with the instance


        :return: The idcs_app_name of this IdcsInfoDetails.
        :rtype: str
        """
        return self._idcs_app_name

    @idcs_app_name.setter
    def idcs_app_name(self, idcs_app_name):
        """
        Sets the idcs_app_name of this IdcsInfoDetails.
        The IDCS application name associated with the instance


        :param idcs_app_name: The idcs_app_name of this IdcsInfoDetails.
        :type: str
        """
        self._idcs_app_name = idcs_app_name

    @property
    def instance_primary_audience_url(self):
        """
        **[Required]** Gets the instance_primary_audience_url of this IdcsInfoDetails.
        The URL used as the primary audience for visual builder flows in this instance
        type: string


        :return: The instance_primary_audience_url of this IdcsInfoDetails.
        :rtype: str
        """
        return self._instance_primary_audience_url

    @instance_primary_audience_url.setter
    def instance_primary_audience_url(self, instance_primary_audience_url):
        """
        Sets the instance_primary_audience_url of this IdcsInfoDetails.
        The URL used as the primary audience for visual builder flows in this instance
        type: string


        :param instance_primary_audience_url: The instance_primary_audience_url of this IdcsInfoDetails.
        :type: str
        """
        self._instance_primary_audience_url = instance_primary_audience_url

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AuditTrailSummary(object):
    """
    Summary of an audit trail.
    """

    #: A constant which can be used with the status property of a AuditTrailSummary.
    #: This constant has a value of "STARTING"
    STATUS_STARTING = "STARTING"

    #: A constant which can be used with the status property of a AuditTrailSummary.
    #: This constant has a value of "COLLECTING"
    STATUS_COLLECTING = "COLLECTING"

    #: A constant which can be used with the status property of a AuditTrailSummary.
    #: This constant has a value of "RECOVERING"
    STATUS_RECOVERING = "RECOVERING"

    #: A constant which can be used with the status property of a AuditTrailSummary.
    #: This constant has a value of "IDLE"
    STATUS_IDLE = "IDLE"

    #: A constant which can be used with the status property of a AuditTrailSummary.
    #: This constant has a value of "STOPPING"
    STATUS_STOPPING = "STOPPING"

    #: A constant which can be used with the status property of a AuditTrailSummary.
    #: This constant has a value of "STOPPED"
    STATUS_STOPPED = "STOPPED"

    #: A constant which can be used with the status property of a AuditTrailSummary.
    #: This constant has a value of "RESUMING"
    STATUS_RESUMING = "RESUMING"

    #: A constant which can be used with the status property of a AuditTrailSummary.
    #: This constant has a value of "RETRYING"
    STATUS_RETRYING = "RETRYING"

    #: A constant which can be used with the lifecycle_state property of a AuditTrailSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AuditTrailSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a AuditTrailSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AuditTrailSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a AuditTrailSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a AuditTrailSummary.
    #: This constant has a value of "NEEDS_ATTENTION"
    LIFECYCLE_STATE_NEEDS_ATTENTION = "NEEDS_ATTENTION"

    def __init__(self, **kwargs):
        """
        Initializes a new AuditTrailSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AuditTrailSummary.
        :type id: str

        :param audit_profile_id:
            The value to assign to the audit_profile_id property of this AuditTrailSummary.
        :type audit_profile_id: str

        :param display_name:
            The value to assign to the display_name property of this AuditTrailSummary.
        :type display_name: str

        :param time_created:
            The value to assign to the time_created property of this AuditTrailSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this AuditTrailSummary.
        :type time_updated: datetime

        :param status:
            The value to assign to the status property of this AuditTrailSummary.
            Allowed values for this property are: "STARTING", "COLLECTING", "RECOVERING", "IDLE", "STOPPING", "STOPPED", "RESUMING", "RETRYING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param description:
            The value to assign to the description property of this AuditTrailSummary.
        :type description: str

        :param trail_location:
            The value to assign to the trail_location property of this AuditTrailSummary.
        :type trail_location: str

        :param compartment_id:
            The value to assign to the compartment_id property of this AuditTrailSummary.
        :type compartment_id: str

        :param target_id:
            The value to assign to the target_id property of this AuditTrailSummary.
        :type target_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AuditTrailSummary.
            Allowed values for this property are: "INACTIVE", "UPDATING", "ACTIVE", "DELETING", "FAILED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this AuditTrailSummary.
        :type lifecycle_details: str

        :param is_auto_purge_enabled:
            The value to assign to the is_auto_purge_enabled property of this AuditTrailSummary.
        :type is_auto_purge_enabled: bool

        :param audit_collection_start_time:
            The value to assign to the audit_collection_start_time property of this AuditTrailSummary.
        :type audit_collection_start_time: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this AuditTrailSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this AuditTrailSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'audit_profile_id': 'str',
            'display_name': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'status': 'str',
            'description': 'str',
            'trail_location': 'str',
            'compartment_id': 'str',
            'target_id': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'is_auto_purge_enabled': 'bool',
            'audit_collection_start_time': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'audit_profile_id': 'auditProfileId',
            'display_name': 'displayName',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'status': 'status',
            'description': 'description',
            'trail_location': 'trailLocation',
            'compartment_id': 'compartmentId',
            'target_id': 'targetId',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'is_auto_purge_enabled': 'isAutoPurgeEnabled',
            'audit_collection_start_time': 'auditCollectionStartTime',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._audit_profile_id = None
        self._display_name = None
        self._time_created = None
        self._time_updated = None
        self._status = None
        self._description = None
        self._trail_location = None
        self._compartment_id = None
        self._target_id = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._is_auto_purge_enabled = None
        self._audit_collection_start_time = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AuditTrailSummary.
        The OCID of the audit trail.


        :return: The id of this AuditTrailSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AuditTrailSummary.
        The OCID of the audit trail.


        :param id: The id of this AuditTrailSummary.
        :type: str
        """
        self._id = id

    @property
    def audit_profile_id(self):
        """
        **[Required]** Gets the audit_profile_id of this AuditTrailSummary.
        The OCID of the  parent audit.


        :return: The audit_profile_id of this AuditTrailSummary.
        :rtype: str
        """
        return self._audit_profile_id

    @audit_profile_id.setter
    def audit_profile_id(self, audit_profile_id):
        """
        Sets the audit_profile_id of this AuditTrailSummary.
        The OCID of the  parent audit.


        :param audit_profile_id: The audit_profile_id of this AuditTrailSummary.
        :type: str
        """
        self._audit_profile_id = audit_profile_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this AuditTrailSummary.
        The display name of the audit trail.


        :return: The display_name of this AuditTrailSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AuditTrailSummary.
        The display name of the audit trail.


        :param display_name: The display_name of this AuditTrailSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this AuditTrailSummary.
        The date and time the audit trail was created, in the format defined by RFC3339.


        :return: The time_created of this AuditTrailSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AuditTrailSummary.
        The date and time the audit trail was created, in the format defined by RFC3339.


        :param time_created: The time_created of this AuditTrailSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this AuditTrailSummary.
        The date and time the audit trail was updated, in the format defined by RFC3339.


        :return: The time_updated of this AuditTrailSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this AuditTrailSummary.
        The date and time the audit trail was updated, in the format defined by RFC3339.


        :param time_updated: The time_updated of this AuditTrailSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def status(self):
        """
        **[Required]** Gets the status of this AuditTrailSummary.
        The current sub-state of the audit trail.

        Allowed values for this property are: "STARTING", "COLLECTING", "RECOVERING", "IDLE", "STOPPING", "STOPPED", "RESUMING", "RETRYING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this AuditTrailSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this AuditTrailSummary.
        The current sub-state of the audit trail.


        :param status: The status of this AuditTrailSummary.
        :type: str
        """
        allowed_values = ["STARTING", "COLLECTING", "RECOVERING", "IDLE", "STOPPING", "STOPPED", "RESUMING", "RETRYING"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def description(self):
        """
        Gets the description of this AuditTrailSummary.
        The description of audit trail.


        :return: The description of this AuditTrailSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AuditTrailSummary.
        The description of audit trail.


        :param description: The description of this AuditTrailSummary.
        :type: str
        """
        self._description = description

    @property
    def trail_location(self):
        """
        Gets the trail_location of this AuditTrailSummary.
        An audit trail location represents the source of audit records that provides documentary evidence of the sequence of activities in the target database.


        :return: The trail_location of this AuditTrailSummary.
        :rtype: str
        """
        return self._trail_location

    @trail_location.setter
    def trail_location(self, trail_location):
        """
        Sets the trail_location of this AuditTrailSummary.
        An audit trail location represents the source of audit records that provides documentary evidence of the sequence of activities in the target database.


        :param trail_location: The trail_location of this AuditTrailSummary.
        :type: str
        """
        self._trail_location = trail_location

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this AuditTrailSummary.
        The OCID of the compartment that contains the audit.


        :return: The compartment_id of this AuditTrailSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AuditTrailSummary.
        The OCID of the compartment that contains the audit.


        :param compartment_id: The compartment_id of this AuditTrailSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def target_id(self):
        """
        **[Required]** Gets the target_id of this AuditTrailSummary.
        The OCID of the Data Safe target for which the audit trail is created.


        :return: The target_id of this AuditTrailSummary.
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """
        Sets the target_id of this AuditTrailSummary.
        The OCID of the Data Safe target for which the audit trail is created.


        :param target_id: The target_id of this AuditTrailSummary.
        :type: str
        """
        self._target_id = target_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this AuditTrailSummary.
        The current state of the audit trail.

        Allowed values for this property are: "INACTIVE", "UPDATING", "ACTIVE", "DELETING", "FAILED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AuditTrailSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AuditTrailSummary.
        The current state of the audit trail.


        :param lifecycle_state: The lifecycle_state of this AuditTrailSummary.
        :type: str
        """
        allowed_values = ["INACTIVE", "UPDATING", "ACTIVE", "DELETING", "FAILED", "NEEDS_ATTENTION"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this AuditTrailSummary.
        Details about the current state of the audit trail in Data Safe.


        :return: The lifecycle_details of this AuditTrailSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this AuditTrailSummary.
        Details about the current state of the audit trail in Data Safe.


        :param lifecycle_details: The lifecycle_details of this AuditTrailSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def is_auto_purge_enabled(self):
        """
        Gets the is_auto_purge_enabled of this AuditTrailSummary.
        Indicates if auto purge is enabled on the target database, which helps delete audit data in the
        target database every seven days so that the database's audit trail does not become too large.


        :return: The is_auto_purge_enabled of this AuditTrailSummary.
        :rtype: bool
        """
        return self._is_auto_purge_enabled

    @is_auto_purge_enabled.setter
    def is_auto_purge_enabled(self, is_auto_purge_enabled):
        """
        Sets the is_auto_purge_enabled of this AuditTrailSummary.
        Indicates if auto purge is enabled on the target database, which helps delete audit data in the
        target database every seven days so that the database's audit trail does not become too large.


        :param is_auto_purge_enabled: The is_auto_purge_enabled of this AuditTrailSummary.
        :type: bool
        """
        self._is_auto_purge_enabled = is_auto_purge_enabled

    @property
    def audit_collection_start_time(self):
        """
        Gets the audit_collection_start_time of this AuditTrailSummary.
        The date from which the audit trail must start collecting data, in the format defined by RFC3339.


        :return: The audit_collection_start_time of this AuditTrailSummary.
        :rtype: datetime
        """
        return self._audit_collection_start_time

    @audit_collection_start_time.setter
    def audit_collection_start_time(self, audit_collection_start_time):
        """
        Sets the audit_collection_start_time of this AuditTrailSummary.
        The date from which the audit trail must start collecting data, in the format defined by RFC3339.


        :param audit_collection_start_time: The audit_collection_start_time of this AuditTrailSummary.
        :type: datetime
        """
        self._audit_collection_start_time = audit_collection_start_time

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this AuditTrailSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this AuditTrailSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this AuditTrailSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this AuditTrailSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this AuditTrailSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this AuditTrailSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this AuditTrailSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this AuditTrailSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DomainReplication(object):
    """
    (For tenancies that support identity domains) Identity domain replication states.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DomainReplication object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param opc_water_mark:
            The value to assign to the opc_water_mark property of this DomainReplication.
        :type opc_water_mark: float

        :param txn_seq_number:
            The value to assign to the txn_seq_number property of this DomainReplication.
        :type txn_seq_number: float

        :param domain_replication_states:
            The value to assign to the domain_replication_states property of this DomainReplication.
        :type domain_replication_states: list[oci.identity.models.DomainReplicationStates]

        """
        self.swagger_types = {
            'opc_water_mark': 'float',
            'txn_seq_number': 'float',
            'domain_replication_states': 'list[DomainReplicationStates]'
        }

        self.attribute_map = {
            'opc_water_mark': 'opcWaterMark',
            'txn_seq_number': 'txnSeqNumber',
            'domain_replication_states': 'domainReplicationStates'
        }

        self._opc_water_mark = None
        self._txn_seq_number = None
        self._domain_replication_states = None

    @property
    def opc_water_mark(self):
        """
        **[Required]** Gets the opc_water_mark of this DomainReplication.
        The version number indicating the value of kievTxnId, starting from which the identity domain replication events need to be returned.


        :return: The opc_water_mark of this DomainReplication.
        :rtype: float
        """
        return self._opc_water_mark

    @opc_water_mark.setter
    def opc_water_mark(self, opc_water_mark):
        """
        Sets the opc_water_mark of this DomainReplication.
        The version number indicating the value of kievTxnId, starting from which the identity domain replication events need to be returned.


        :param opc_water_mark: The opc_water_mark of this DomainReplication.
        :type: float
        """
        self._opc_water_mark = opc_water_mark

    @property
    def txn_seq_number(self):
        """
        **[Required]** Gets the txn_seq_number of this DomainReplication.
        A custom value defining the order of records with the same kievTxnId.


        :return: The txn_seq_number of this DomainReplication.
        :rtype: float
        """
        return self._txn_seq_number

    @txn_seq_number.setter
    def txn_seq_number(self, txn_seq_number):
        """
        Sets the txn_seq_number of this DomainReplication.
        A custom value defining the order of records with the same kievTxnId.


        :param txn_seq_number: The txn_seq_number of this DomainReplication.
        :type: float
        """
        self._txn_seq_number = txn_seq_number

    @property
    def domain_replication_states(self):
        """
        **[Required]** Gets the domain_replication_states of this DomainReplication.
        The identity domain's replication state.


        :return: The domain_replication_states of this DomainReplication.
        :rtype: list[oci.identity.models.DomainReplicationStates]
        """
        return self._domain_replication_states

    @domain_replication_states.setter
    def domain_replication_states(self, domain_replication_states):
        """
        Sets the domain_replication_states of this DomainReplication.
        The identity domain's replication state.


        :param domain_replication_states: The domain_replication_states of this DomainReplication.
        :type: list[oci.identity.models.DomainReplicationStates]
        """
        self._domain_replication_states = domain_replication_states

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateTranscriptionJobDetails(object):
    """
    The information about new Transcription Job.
    """

    #: A constant which can be used with the additional_transcription_formats property of a CreateTranscriptionJobDetails.
    #: This constant has a value of "SRT"
    ADDITIONAL_TRANSCRIPTION_FORMATS_SRT = "SRT"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateTranscriptionJobDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateTranscriptionJobDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateTranscriptionJobDetails.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this CreateTranscriptionJobDetails.
        :type description: str

        :param additional_transcription_formats:
            The value to assign to the additional_transcription_formats property of this CreateTranscriptionJobDetails.
            Allowed values for items in this list are: "SRT"
        :type additional_transcription_formats: list[str]

        :param model_details:
            The value to assign to the model_details property of this CreateTranscriptionJobDetails.
        :type model_details: oci.ai_speech.models.TranscriptionModelDetails

        :param normalization:
            The value to assign to the normalization property of this CreateTranscriptionJobDetails.
        :type normalization: oci.ai_speech.models.TranscriptionNormalization

        :param input_location:
            The value to assign to the input_location property of this CreateTranscriptionJobDetails.
        :type input_location: oci.ai_speech.models.InputLocation

        :param output_location:
            The value to assign to the output_location property of this CreateTranscriptionJobDetails.
        :type output_location: oci.ai_speech.models.OutputLocation

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateTranscriptionJobDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateTranscriptionJobDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'description': 'str',
            'additional_transcription_formats': 'list[str]',
            'model_details': 'TranscriptionModelDetails',
            'normalization': 'TranscriptionNormalization',
            'input_location': 'InputLocation',
            'output_location': 'OutputLocation',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'description': 'description',
            'additional_transcription_formats': 'additionalTranscriptionFormats',
            'model_details': 'modelDetails',
            'normalization': 'normalization',
            'input_location': 'inputLocation',
            'output_location': 'outputLocation',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._compartment_id = None
        self._description = None
        self._additional_transcription_formats = None
        self._model_details = None
        self._normalization = None
        self._input_location = None
        self._output_location = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateTranscriptionJobDetails.
        A user-friendly display name for the job.


        :return: The display_name of this CreateTranscriptionJobDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateTranscriptionJobDetails.
        A user-friendly display name for the job.


        :param display_name: The display_name of this CreateTranscriptionJobDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateTranscriptionJobDetails.
        The `OCID`__ of the compartment where you want to create the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateTranscriptionJobDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateTranscriptionJobDetails.
        The `OCID`__ of the compartment where you want to create the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateTranscriptionJobDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this CreateTranscriptionJobDetails.
        A short description of the job.


        :return: The description of this CreateTranscriptionJobDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateTranscriptionJobDetails.
        A short description of the job.


        :param description: The description of this CreateTranscriptionJobDetails.
        :type: str
        """
        self._description = description

    @property
    def additional_transcription_formats(self):
        """
        Gets the additional_transcription_formats of this CreateTranscriptionJobDetails.
        Transcription Format. By default JSON format will be considered.

        Allowed values for items in this list are: "SRT"


        :return: The additional_transcription_formats of this CreateTranscriptionJobDetails.
        :rtype: list[str]
        """
        return self._additional_transcription_formats

    @additional_transcription_formats.setter
    def additional_transcription_formats(self, additional_transcription_formats):
        """
        Sets the additional_transcription_formats of this CreateTranscriptionJobDetails.
        Transcription Format. By default JSON format will be considered.


        :param additional_transcription_formats: The additional_transcription_formats of this CreateTranscriptionJobDetails.
        :type: list[str]
        """
        allowed_values = ["SRT"]

        if additional_transcription_formats and additional_transcription_formats is not NONE_SENTINEL:
            for value in additional_transcription_formats:
                if not value_allowed_none_or_none_sentinel(value, allowed_values):
                    raise ValueError(
                        "Invalid value for `additional_transcription_formats`, must be None or one of {0}"
                        .format(allowed_values)
                    )
        self._additional_transcription_formats = additional_transcription_formats

    @property
    def model_details(self):
        """
        Gets the model_details of this CreateTranscriptionJobDetails.

        :return: The model_details of this CreateTranscriptionJobDetails.
        :rtype: oci.ai_speech.models.TranscriptionModelDetails
        """
        return self._model_details

    @model_details.setter
    def model_details(self, model_details):
        """
        Sets the model_details of this CreateTranscriptionJobDetails.

        :param model_details: The model_details of this CreateTranscriptionJobDetails.
        :type: oci.ai_speech.models.TranscriptionModelDetails
        """
        self._model_details = model_details

    @property
    def normalization(self):
        """
        Gets the normalization of this CreateTranscriptionJobDetails.

        :return: The normalization of this CreateTranscriptionJobDetails.
        :rtype: oci.ai_speech.models.TranscriptionNormalization
        """
        return self._normalization

    @normalization.setter
    def normalization(self, normalization):
        """
        Sets the normalization of this CreateTranscriptionJobDetails.

        :param normalization: The normalization of this CreateTranscriptionJobDetails.
        :type: oci.ai_speech.models.TranscriptionNormalization
        """
        self._normalization = normalization

    @property
    def input_location(self):
        """
        **[Required]** Gets the input_location of this CreateTranscriptionJobDetails.

        :return: The input_location of this CreateTranscriptionJobDetails.
        :rtype: oci.ai_speech.models.InputLocation
        """
        return self._input_location

    @input_location.setter
    def input_location(self, input_location):
        """
        Sets the input_location of this CreateTranscriptionJobDetails.

        :param input_location: The input_location of this CreateTranscriptionJobDetails.
        :type: oci.ai_speech.models.InputLocation
        """
        self._input_location = input_location

    @property
    def output_location(self):
        """
        **[Required]** Gets the output_location of this CreateTranscriptionJobDetails.

        :return: The output_location of this CreateTranscriptionJobDetails.
        :rtype: oci.ai_speech.models.OutputLocation
        """
        return self._output_location

    @output_location.setter
    def output_location(self, output_location):
        """
        Sets the output_location of this CreateTranscriptionJobDetails.

        :param output_location: The output_location of this CreateTranscriptionJobDetails.
        :type: oci.ai_speech.models.OutputLocation
        """
        self._output_location = output_location

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateTranscriptionJobDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateTranscriptionJobDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateTranscriptionJobDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateTranscriptionJobDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateTranscriptionJobDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateTranscriptionJobDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateTranscriptionJobDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateTranscriptionJobDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SmtpCredential(object):
    """
    Simple Mail Transfer Protocol (SMTP) credentials are needed to send email through Email Delivery.
    The SMTP credentials are used for SMTP authentication with the service. The credentials never expire.
    A user can have up to 2 SMTP credentials at a time.

    **Note:** The credential set is always an Oracle-generated SMTP user name and password pair;
    you cannot designate the SMTP user name or the SMTP password.

    For more information, see `Managing User Credentials`__.

    __ https://docs.cloud.oracle.com/Content/Identity/access/managing-user-credentials.htm#SMTP
    """

    #: A constant which can be used with the lifecycle_state property of a SmtpCredential.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a SmtpCredential.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SmtpCredential.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SmtpCredential.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a SmtpCredential.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new SmtpCredential object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param username:
            The value to assign to the username property of this SmtpCredential.
        :type username: str

        :param password:
            The value to assign to the password property of this SmtpCredential.
        :type password: str

        :param id:
            The value to assign to the id property of this SmtpCredential.
        :type id: str

        :param user_id:
            The value to assign to the user_id property of this SmtpCredential.
        :type user_id: str

        :param description:
            The value to assign to the description property of this SmtpCredential.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this SmtpCredential.
        :type time_created: datetime

        :param time_expires:
            The value to assign to the time_expires property of this SmtpCredential.
        :type time_expires: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SmtpCredential.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param inactive_status:
            The value to assign to the inactive_status property of this SmtpCredential.
        :type inactive_status: int

        """
        self.swagger_types = {
            'username': 'str',
            'password': 'str',
            'id': 'str',
            'user_id': 'str',
            'description': 'str',
            'time_created': 'datetime',
            'time_expires': 'datetime',
            'lifecycle_state': 'str',
            'inactive_status': 'int'
        }

        self.attribute_map = {
            'username': 'username',
            'password': 'password',
            'id': 'id',
            'user_id': 'userId',
            'description': 'description',
            'time_created': 'timeCreated',
            'time_expires': 'timeExpires',
            'lifecycle_state': 'lifecycleState',
            'inactive_status': 'inactiveStatus'
        }

        self._username = None
        self._password = None
        self._id = None
        self._user_id = None
        self._description = None
        self._time_created = None
        self._time_expires = None
        self._lifecycle_state = None
        self._inactive_status = None

    @property
    def username(self):
        """
        Gets the username of this SmtpCredential.
        The SMTP user name.


        :return: The username of this SmtpCredential.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this SmtpCredential.
        The SMTP user name.


        :param username: The username of this SmtpCredential.
        :type: str
        """
        self._username = username

    @property
    def password(self):
        """
        Gets the password of this SmtpCredential.
        The SMTP password.


        :return: The password of this SmtpCredential.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this SmtpCredential.
        The SMTP password.


        :param password: The password of this SmtpCredential.
        :type: str
        """
        self._password = password

    @property
    def id(self):
        """
        Gets the id of this SmtpCredential.
        The OCID of the SMTP credential.


        :return: The id of this SmtpCredential.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SmtpCredential.
        The OCID of the SMTP credential.


        :param id: The id of this SmtpCredential.
        :type: str
        """
        self._id = id

    @property
    def user_id(self):
        """
        Gets the user_id of this SmtpCredential.
        The OCID of the user the SMTP credential belongs to.


        :return: The user_id of this SmtpCredential.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this SmtpCredential.
        The OCID of the user the SMTP credential belongs to.


        :param user_id: The user_id of this SmtpCredential.
        :type: str
        """
        self._user_id = user_id

    @property
    def description(self):
        """
        Gets the description of this SmtpCredential.
        The description you assign to the SMTP credential. Does not have to be unique, and it's changeable.

        (For tenancies that support identity domains) You can have an empty description.


        :return: The description of this SmtpCredential.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SmtpCredential.
        The description you assign to the SMTP credential. Does not have to be unique, and it's changeable.

        (For tenancies that support identity domains) You can have an empty description.


        :param description: The description of this SmtpCredential.
        :type: str
        """
        self._description = description

    @property
    def time_created(self):
        """
        Gets the time_created of this SmtpCredential.
        Date and time the `SmtpCredential` object was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this SmtpCredential.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SmtpCredential.
        Date and time the `SmtpCredential` object was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this SmtpCredential.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_expires(self):
        """
        Gets the time_expires of this SmtpCredential.
        Date and time when this credential will expire, in the format defined by RFC3339.
        Null if it never expires.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_expires of this SmtpCredential.
        :rtype: datetime
        """
        return self._time_expires

    @time_expires.setter
    def time_expires(self, time_expires):
        """
        Sets the time_expires of this SmtpCredential.
        Date and time when this credential will expire, in the format defined by RFC3339.
        Null if it never expires.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_expires: The time_expires of this SmtpCredential.
        :type: datetime
        """
        self._time_expires = time_expires

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this SmtpCredential.
        The credential's current state. After creating a SMTP credential, make sure its `lifecycleState` changes from
        CREATING to ACTIVE before using it.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SmtpCredential.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SmtpCredential.
        The credential's current state. After creating a SMTP credential, make sure its `lifecycleState` changes from
        CREATING to ACTIVE before using it.


        :param lifecycle_state: The lifecycle_state of this SmtpCredential.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def inactive_status(self):
        """
        Gets the inactive_status of this SmtpCredential.
        The detailed status of INACTIVE lifecycleState.


        :return: The inactive_status of this SmtpCredential.
        :rtype: int
        """
        return self._inactive_status

    @inactive_status.setter
    def inactive_status(self, inactive_status):
        """
        Sets the inactive_status of this SmtpCredential.
        The detailed status of INACTIVE lifecycleState.


        :param inactive_status: The inactive_status of this SmtpCredential.
        :type: int
        """
        self._inactive_status = inactive_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AuthenticationProvider(object):
    """
    Settings for the Authentication Provider.
    """

    #: A constant which can be used with the grant_type property of a AuthenticationProvider.
    #: This constant has a value of "CLIENT_CREDENTIALS"
    GRANT_TYPE_CLIENT_CREDENTIALS = "CLIENT_CREDENTIALS"

    #: A constant which can be used with the grant_type property of a AuthenticationProvider.
    #: This constant has a value of "AUTHORIZATION_CODE"
    GRANT_TYPE_AUTHORIZATION_CODE = "AUTHORIZATION_CODE"

    #: A constant which can be used with the identity_provider property of a AuthenticationProvider.
    #: This constant has a value of "GENERIC"
    IDENTITY_PROVIDER_GENERIC = "GENERIC"

    #: A constant which can be used with the identity_provider property of a AuthenticationProvider.
    #: This constant has a value of "OAM"
    IDENTITY_PROVIDER_OAM = "OAM"

    #: A constant which can be used with the identity_provider property of a AuthenticationProvider.
    #: This constant has a value of "GOOGLE"
    IDENTITY_PROVIDER_GOOGLE = "GOOGLE"

    #: A constant which can be used with the identity_provider property of a AuthenticationProvider.
    #: This constant has a value of "MICROSOFT"
    IDENTITY_PROVIDER_MICROSOFT = "MICROSOFT"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProvider.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProvider.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProvider.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProvider.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProvider.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProvider.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProvider.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new AuthenticationProvider object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AuthenticationProvider.
        :type id: str

        :param grant_type:
            The value to assign to the grant_type property of this AuthenticationProvider.
            Allowed values for this property are: "CLIENT_CREDENTIALS", "AUTHORIZATION_CODE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type grant_type: str

        :param identity_provider:
            The value to assign to the identity_provider property of this AuthenticationProvider.
            Allowed values for this property are: "GENERIC", "OAM", "GOOGLE", "MICROSOFT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type identity_provider: str

        :param name:
            The value to assign to the name property of this AuthenticationProvider.
        :type name: str

        :param token_endpoint_url:
            The value to assign to the token_endpoint_url property of this AuthenticationProvider.
        :type token_endpoint_url: str

        :param authorization_endpoint_url:
            The value to assign to the authorization_endpoint_url property of this AuthenticationProvider.
        :type authorization_endpoint_url: str

        :param short_authorization_code_request_url:
            The value to assign to the short_authorization_code_request_url property of this AuthenticationProvider.
        :type short_authorization_code_request_url: str

        :param revoke_token_endpoint_url:
            The value to assign to the revoke_token_endpoint_url property of this AuthenticationProvider.
        :type revoke_token_endpoint_url: str

        :param client_id:
            The value to assign to the client_id property of this AuthenticationProvider.
        :type client_id: str

        :param scopes:
            The value to assign to the scopes property of this AuthenticationProvider.
        :type scopes: str

        :param subject_claim:
            The value to assign to the subject_claim property of this AuthenticationProvider.
        :type subject_claim: str

        :param refresh_token_retention_period_in_days:
            The value to assign to the refresh_token_retention_period_in_days property of this AuthenticationProvider.
        :type refresh_token_retention_period_in_days: int

        :param redirect_url:
            The value to assign to the redirect_url property of this AuthenticationProvider.
        :type redirect_url: str

        :param is_visible:
            The value to assign to the is_visible property of this AuthenticationProvider.
        :type is_visible: bool

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AuthenticationProvider.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this AuthenticationProvider.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this AuthenticationProvider.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this AuthenticationProvider.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this AuthenticationProvider.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'grant_type': 'str',
            'identity_provider': 'str',
            'name': 'str',
            'token_endpoint_url': 'str',
            'authorization_endpoint_url': 'str',
            'short_authorization_code_request_url': 'str',
            'revoke_token_endpoint_url': 'str',
            'client_id': 'str',
            'scopes': 'str',
            'subject_claim': 'str',
            'refresh_token_retention_period_in_days': 'int',
            'redirect_url': 'str',
            'is_visible': 'bool',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'grant_type': 'grantType',
            'identity_provider': 'identityProvider',
            'name': 'name',
            'token_endpoint_url': 'tokenEndpointUrl',
            'authorization_endpoint_url': 'authorizationEndpointUrl',
            'short_authorization_code_request_url': 'shortAuthorizationCodeRequestUrl',
            'revoke_token_endpoint_url': 'revokeTokenEndpointUrl',
            'client_id': 'clientId',
            'scopes': 'scopes',
            'subject_claim': 'subjectClaim',
            'refresh_token_retention_period_in_days': 'refreshTokenRetentionPeriodInDays',
            'redirect_url': 'redirectUrl',
            'is_visible': 'isVisible',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._grant_type = None
        self._identity_provider = None
        self._name = None
        self._token_endpoint_url = None
        self._authorization_endpoint_url = None
        self._short_authorization_code_request_url = None
        self._revoke_token_endpoint_url = None
        self._client_id = None
        self._scopes = None
        self._subject_claim = None
        self._refresh_token_retention_period_in_days = None
        self._redirect_url = None
        self._is_visible = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AuthenticationProvider.
        Unique immutable identifier that was assigned when the Authentication Provider was created.


        :return: The id of this AuthenticationProvider.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AuthenticationProvider.
        Unique immutable identifier that was assigned when the Authentication Provider was created.


        :param id: The id of this AuthenticationProvider.
        :type: str
        """
        self._id = id

    @property
    def grant_type(self):
        """
        **[Required]** Gets the grant_type of this AuthenticationProvider.
        The grant type for the Authentication Provider.

        Allowed values for this property are: "CLIENT_CREDENTIALS", "AUTHORIZATION_CODE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The grant_type of this AuthenticationProvider.
        :rtype: str
        """
        return self._grant_type

    @grant_type.setter
    def grant_type(self, grant_type):
        """
        Sets the grant_type of this AuthenticationProvider.
        The grant type for the Authentication Provider.


        :param grant_type: The grant_type of this AuthenticationProvider.
        :type: str
        """
        allowed_values = ["CLIENT_CREDENTIALS", "AUTHORIZATION_CODE"]
        if not value_allowed_none_or_none_sentinel(grant_type, allowed_values):
            grant_type = 'UNKNOWN_ENUM_VALUE'
        self._grant_type = grant_type

    @property
    def identity_provider(self):
        """
        **[Required]** Gets the identity_provider of this AuthenticationProvider.
        Which type of Identity Provider (IDP) you are using.

        Allowed values for this property are: "GENERIC", "OAM", "GOOGLE", "MICROSOFT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The identity_provider of this AuthenticationProvider.
        :rtype: str
        """
        return self._identity_provider

    @identity_provider.setter
    def identity_provider(self, identity_provider):
        """
        Sets the identity_provider of this AuthenticationProvider.
        Which type of Identity Provider (IDP) you are using.


        :param identity_provider: The identity_provider of this AuthenticationProvider.
        :type: str
        """
        allowed_values = ["GENERIC", "OAM", "GOOGLE", "MICROSOFT"]
        if not value_allowed_none_or_none_sentinel(identity_provider, allowed_values):
            identity_provider = 'UNKNOWN_ENUM_VALUE'
        self._identity_provider = identity_provider

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AuthenticationProvider.
        A name to identify the Authentication Provider.


        :return: The name of this AuthenticationProvider.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AuthenticationProvider.
        A name to identify the Authentication Provider.


        :param name: The name of this AuthenticationProvider.
        :type: str
        """
        self._name = name

    @property
    def token_endpoint_url(self):
        """
        **[Required]** Gets the token_endpoint_url of this AuthenticationProvider.
        The IDPs URL for requesting access tokens.


        :return: The token_endpoint_url of this AuthenticationProvider.
        :rtype: str
        """
        return self._token_endpoint_url

    @token_endpoint_url.setter
    def token_endpoint_url(self, token_endpoint_url):
        """
        Sets the token_endpoint_url of this AuthenticationProvider.
        The IDPs URL for requesting access tokens.


        :param token_endpoint_url: The token_endpoint_url of this AuthenticationProvider.
        :type: str
        """
        self._token_endpoint_url = token_endpoint_url

    @property
    def authorization_endpoint_url(self):
        """
        **[Required]** Gets the authorization_endpoint_url of this AuthenticationProvider.
        The IDPs URL for the page that users authenticate with by entering the user name and password.


        :return: The authorization_endpoint_url of this AuthenticationProvider.
        :rtype: str
        """
        return self._authorization_endpoint_url

    @authorization_endpoint_url.setter
    def authorization_endpoint_url(self, authorization_endpoint_url):
        """
        Sets the authorization_endpoint_url of this AuthenticationProvider.
        The IDPs URL for the page that users authenticate with by entering the user name and password.


        :param authorization_endpoint_url: The authorization_endpoint_url of this AuthenticationProvider.
        :type: str
        """
        self._authorization_endpoint_url = authorization_endpoint_url

    @property
    def short_authorization_code_request_url(self):
        """
        Gets the short_authorization_code_request_url of this AuthenticationProvider.
        A shortened version of the authorization URL, which you can get from a URL shortener service (one that allows
        you to send query parameters).  You might need this because the generated authorization-code-request URL
        could be too long for SMS and older smart phones.


        :return: The short_authorization_code_request_url of this AuthenticationProvider.
        :rtype: str
        """
        return self._short_authorization_code_request_url

    @short_authorization_code_request_url.setter
    def short_authorization_code_request_url(self, short_authorization_code_request_url):
        """
        Sets the short_authorization_code_request_url of this AuthenticationProvider.
        A shortened version of the authorization URL, which you can get from a URL shortener service (one that allows
        you to send query parameters).  You might need this because the generated authorization-code-request URL
        could be too long for SMS and older smart phones.


        :param short_authorization_code_request_url: The short_authorization_code_request_url of this AuthenticationProvider.
        :type: str
        """
        self._short_authorization_code_request_url = short_authorization_code_request_url

    @property
    def revoke_token_endpoint_url(self):
        """
        Gets the revoke_token_endpoint_url of this AuthenticationProvider.
        If you want to revoke all the refresh tokens and access tokens of the logged-in user from a dialog flow, then
        you need the IDP's revoke refresh token URL. If you provide this URL, then you can use the System.OAuth2ResetTokens
        component to revoke the user's tokens for this service.


        :return: The revoke_token_endpoint_url of this AuthenticationProvider.
        :rtype: str
        """
        return self._revoke_token_endpoint_url

    @revoke_token_endpoint_url.setter
    def revoke_token_endpoint_url(self, revoke_token_endpoint_url):
        """
        Sets the revoke_token_endpoint_url of this AuthenticationProvider.
        If you want to revoke all the refresh tokens and access tokens of the logged-in user from a dialog flow, then
        you need the IDP's revoke refresh token URL. If you provide this URL, then you can use the System.OAuth2ResetTokens
        component to revoke the user's tokens for this service.


        :param revoke_token_endpoint_url: The revoke_token_endpoint_url of this AuthenticationProvider.
        :type: str
        """
        self._revoke_token_endpoint_url = revoke_token_endpoint_url

    @property
    def client_id(self):
        """
        **[Required]** Gets the client_id of this AuthenticationProvider.
        The client ID for the IDP application (OAuth Client) that was registered as described in Identity Provider Registration.
        With Microsoft identity platform, use the application ID.


        :return: The client_id of this AuthenticationProvider.
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """
        Sets the client_id of this AuthenticationProvider.
        The client ID for the IDP application (OAuth Client) that was registered as described in Identity Provider Registration.
        With Microsoft identity platform, use the application ID.


        :param client_id: The client_id of this AuthenticationProvider.
        :type: str
        """
        self._client_id = client_id

    @property
    def scopes(self):
        """
        **[Required]** Gets the scopes of this AuthenticationProvider.
        A space-separated list of the scopes that must be included when Digital Assistant requests an access token from
        the provider. Include all the scopes that are required to access the resources. If refresh tokens are enabled,
        include the scope that\u2019s necessary to get the refresh token (typically offline_access).


        :return: The scopes of this AuthenticationProvider.
        :rtype: str
        """
        return self._scopes

    @scopes.setter
    def scopes(self, scopes):
        """
        Sets the scopes of this AuthenticationProvider.
        A space-separated list of the scopes that must be included when Digital Assistant requests an access token from
        the provider. Include all the scopes that are required to access the resources. If refresh tokens are enabled,
        include the scope that\u2019s necessary to get the refresh token (typically offline_access).


        :param scopes: The scopes of this AuthenticationProvider.
        :type: str
        """
        self._scopes = scopes

    @property
    def subject_claim(self):
        """
        **[Required]** Gets the subject_claim of this AuthenticationProvider.
        The access-token profile claim to use to identify the user.


        :return: The subject_claim of this AuthenticationProvider.
        :rtype: str
        """
        return self._subject_claim

    @subject_claim.setter
    def subject_claim(self, subject_claim):
        """
        Sets the subject_claim of this AuthenticationProvider.
        The access-token profile claim to use to identify the user.


        :param subject_claim: The subject_claim of this AuthenticationProvider.
        :type: str
        """
        self._subject_claim = subject_claim

    @property
    def refresh_token_retention_period_in_days(self):
        """
        Gets the refresh_token_retention_period_in_days of this AuthenticationProvider.
        The number of days to keep the refresh token in the Digital Assistant cache.


        :return: The refresh_token_retention_period_in_days of this AuthenticationProvider.
        :rtype: int
        """
        return self._refresh_token_retention_period_in_days

    @refresh_token_retention_period_in_days.setter
    def refresh_token_retention_period_in_days(self, refresh_token_retention_period_in_days):
        """
        Sets the refresh_token_retention_period_in_days of this AuthenticationProvider.
        The number of days to keep the refresh token in the Digital Assistant cache.


        :param refresh_token_retention_period_in_days: The refresh_token_retention_period_in_days of this AuthenticationProvider.
        :type: int
        """
        self._refresh_token_retention_period_in_days = refresh_token_retention_period_in_days

    @property
    def redirect_url(self):
        """
        Gets the redirect_url of this AuthenticationProvider.
        The OAuth Redirect URL.


        :return: The redirect_url of this AuthenticationProvider.
        :rtype: str
        """
        return self._redirect_url

    @redirect_url.setter
    def redirect_url(self, redirect_url):
        """
        Sets the redirect_url of this AuthenticationProvider.
        The OAuth Redirect URL.


        :param redirect_url: The redirect_url of this AuthenticationProvider.
        :type: str
        """
        self._redirect_url = redirect_url

    @property
    def is_visible(self):
        """
        **[Required]** Gets the is_visible of this AuthenticationProvider.
        Whether this Authentication Provider is visible in the ODA UI.


        :return: The is_visible of this AuthenticationProvider.
        :rtype: bool
        """
        return self._is_visible

    @is_visible.setter
    def is_visible(self, is_visible):
        """
        Sets the is_visible of this AuthenticationProvider.
        Whether this Authentication Provider is visible in the ODA UI.


        :param is_visible: The is_visible of this AuthenticationProvider.
        :type: bool
        """
        self._is_visible = is_visible

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this AuthenticationProvider.
        The Authentication Provider's current state.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AuthenticationProvider.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AuthenticationProvider.
        The Authentication Provider's current state.


        :param lifecycle_state: The lifecycle_state of this AuthenticationProvider.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this AuthenticationProvider.
        When the resource was created. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this AuthenticationProvider.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AuthenticationProvider.
        When the resource was created. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this AuthenticationProvider.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this AuthenticationProvider.
        When the resource was last updated. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_updated of this AuthenticationProvider.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this AuthenticationProvider.
        When the resource was last updated. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_updated: The time_updated of this AuthenticationProvider.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this AuthenticationProvider.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this AuthenticationProvider.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this AuthenticationProvider.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this AuthenticationProvider.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this AuthenticationProvider.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this AuthenticationProvider.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this AuthenticationProvider.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this AuthenticationProvider.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MetricBasedHorizontalScaleInConfig(object):
    """
    Configration for a metric based horizontal scale-in policy.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MetricBasedHorizontalScaleInConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric:
            The value to assign to the metric property of this MetricBasedHorizontalScaleInConfig.
        :type metric: oci.bds.models.AutoScalePolicyMetricRule

        :param min_node_count:
            The value to assign to the min_node_count property of this MetricBasedHorizontalScaleInConfig.
        :type min_node_count: int

        :param step_size:
            The value to assign to the step_size property of this MetricBasedHorizontalScaleInConfig.
        :type step_size: int

        """
        self.swagger_types = {
            'metric': 'AutoScalePolicyMetricRule',
            'min_node_count': 'int',
            'step_size': 'int'
        }

        self.attribute_map = {
            'metric': 'metric',
            'min_node_count': 'minNodeCount',
            'step_size': 'stepSize'
        }

        self._metric = None
        self._min_node_count = None
        self._step_size = None

    @property
    def metric(self):
        """
        Gets the metric of this MetricBasedHorizontalScaleInConfig.

        :return: The metric of this MetricBasedHorizontalScaleInConfig.
        :rtype: oci.bds.models.AutoScalePolicyMetricRule
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this MetricBasedHorizontalScaleInConfig.

        :param metric: The metric of this MetricBasedHorizontalScaleInConfig.
        :type: oci.bds.models.AutoScalePolicyMetricRule
        """
        self._metric = metric

    @property
    def min_node_count(self):
        """
        Gets the min_node_count of this MetricBasedHorizontalScaleInConfig.
        This value is the minimum number of nodes the cluster can be scaled-in to.


        :return: The min_node_count of this MetricBasedHorizontalScaleInConfig.
        :rtype: int
        """
        return self._min_node_count

    @min_node_count.setter
    def min_node_count(self, min_node_count):
        """
        Sets the min_node_count of this MetricBasedHorizontalScaleInConfig.
        This value is the minimum number of nodes the cluster can be scaled-in to.


        :param min_node_count: The min_node_count of this MetricBasedHorizontalScaleInConfig.
        :type: int
        """
        self._min_node_count = min_node_count

    @property
    def step_size(self):
        """
        Gets the step_size of this MetricBasedHorizontalScaleInConfig.
        This value is the number of nodes to remove during a scale-in event.


        :return: The step_size of this MetricBasedHorizontalScaleInConfig.
        :rtype: int
        """
        return self._step_size

    @step_size.setter
    def step_size(self, step_size):
        """
        Sets the step_size of this MetricBasedHorizontalScaleInConfig.
        This value is the number of nodes to remove during a scale-in event.


        :param step_size: The step_size of this MetricBasedHorizontalScaleInConfig.
        :type: int
        """
        self._step_size = step_size

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .exadata_insight_summary import ExadataInsightSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EmManagedExternalExadataInsightSummary(ExadataInsightSummary):
    """
    Summary of an Exadata insight resource.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EmManagedExternalExadataInsightSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.EmManagedExternalExadataInsightSummary.entity_source` attribute
        of this class is ``EM_MANAGED_EXTERNAL_EXADATA`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_source:
            The value to assign to the entity_source property of this EmManagedExternalExadataInsightSummary.
            Allowed values for this property are: "EM_MANAGED_EXTERNAL_EXADATA"
        :type entity_source: str

        :param id:
            The value to assign to the id property of this EmManagedExternalExadataInsightSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this EmManagedExternalExadataInsightSummary.
        :type compartment_id: str

        :param exadata_name:
            The value to assign to the exadata_name property of this EmManagedExternalExadataInsightSummary.
        :type exadata_name: str

        :param exadata_display_name:
            The value to assign to the exadata_display_name property of this EmManagedExternalExadataInsightSummary.
        :type exadata_display_name: str

        :param exadata_type:
            The value to assign to the exadata_type property of this EmManagedExternalExadataInsightSummary.
            Allowed values for this property are: "DBMACHINE", "EXACS", "EXACC"
        :type exadata_type: str

        :param exadata_rack_type:
            The value to assign to the exadata_rack_type property of this EmManagedExternalExadataInsightSummary.
            Allowed values for this property are: "FULL", "HALF", "QUARTER", "EIGHTH"
        :type exadata_rack_type: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this EmManagedExternalExadataInsightSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this EmManagedExternalExadataInsightSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this EmManagedExternalExadataInsightSummary.
        :type system_tags: dict(str, dict(str, object))

        :param status:
            The value to assign to the status property of this EmManagedExternalExadataInsightSummary.
            Allowed values for this property are: "DISABLED", "ENABLED", "TERMINATED"
        :type status: str

        :param time_created:
            The value to assign to the time_created property of this EmManagedExternalExadataInsightSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this EmManagedExternalExadataInsightSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this EmManagedExternalExadataInsightSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this EmManagedExternalExadataInsightSummary.
        :type lifecycle_details: str

        :param enterprise_manager_identifier:
            The value to assign to the enterprise_manager_identifier property of this EmManagedExternalExadataInsightSummary.
        :type enterprise_manager_identifier: str

        :param enterprise_manager_entity_name:
            The value to assign to the enterprise_manager_entity_name property of this EmManagedExternalExadataInsightSummary.
        :type enterprise_manager_entity_name: str

        :param enterprise_manager_entity_type:
            The value to assign to the enterprise_manager_entity_type property of this EmManagedExternalExadataInsightSummary.
        :type enterprise_manager_entity_type: str

        :param enterprise_manager_entity_identifier:
            The value to assign to the enterprise_manager_entity_identifier property of this EmManagedExternalExadataInsightSummary.
        :type enterprise_manager_entity_identifier: str

        :param enterprise_manager_entity_display_name:
            The value to assign to the enterprise_manager_entity_display_name property of this EmManagedExternalExadataInsightSummary.
        :type enterprise_manager_entity_display_name: str

        :param enterprise_manager_bridge_id:
            The value to assign to the enterprise_manager_bridge_id property of this EmManagedExternalExadataInsightSummary.
        :type enterprise_manager_bridge_id: str

        """
        self.swagger_types = {
            'entity_source': 'str',
            'id': 'str',
            'compartment_id': 'str',
            'exadata_name': 'str',
            'exadata_display_name': 'str',
            'exadata_type': 'str',
            'exadata_rack_type': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'status': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'enterprise_manager_identifier': 'str',
            'enterprise_manager_entity_name': 'str',
            'enterprise_manager_entity_type': 'str',
            'enterprise_manager_entity_identifier': 'str',
            'enterprise_manager_entity_display_name': 'str',
            'enterprise_manager_bridge_id': 'str'
        }

        self.attribute_map = {
            'entity_source': 'entitySource',
            'id': 'id',
            'compartment_id': 'compartmentId',
            'exadata_name': 'exadataName',
            'exadata_display_name': 'exadataDisplayName',
            'exadata_type': 'exadataType',
            'exadata_rack_type': 'exadataRackType',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'status': 'status',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'enterprise_manager_identifier': 'enterpriseManagerIdentifier',
            'enterprise_manager_entity_name': 'enterpriseManagerEntityName',
            'enterprise_manager_entity_type': 'enterpriseManagerEntityType',
            'enterprise_manager_entity_identifier': 'enterpriseManagerEntityIdentifier',
            'enterprise_manager_entity_display_name': 'enterpriseManagerEntityDisplayName',
            'enterprise_manager_bridge_id': 'enterpriseManagerBridgeId'
        }

        self._entity_source = None
        self._id = None
        self._compartment_id = None
        self._exadata_name = None
        self._exadata_display_name = None
        self._exadata_type = None
        self._exadata_rack_type = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._status = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._enterprise_manager_identifier = None
        self._enterprise_manager_entity_name = None
        self._enterprise_manager_entity_type = None
        self._enterprise_manager_entity_identifier = None
        self._enterprise_manager_entity_display_name = None
        self._enterprise_manager_bridge_id = None
        self._entity_source = 'EM_MANAGED_EXTERNAL_EXADATA'

    @property
    def enterprise_manager_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_identifier of this EmManagedExternalExadataInsightSummary.
        Enterprise Manager Unique Identifier


        :return: The enterprise_manager_identifier of this EmManagedExternalExadataInsightSummary.
        :rtype: str
        """
        return self._enterprise_manager_identifier

    @enterprise_manager_identifier.setter
    def enterprise_manager_identifier(self, enterprise_manager_identifier):
        """
        Sets the enterprise_manager_identifier of this EmManagedExternalExadataInsightSummary.
        Enterprise Manager Unique Identifier


        :param enterprise_manager_identifier: The enterprise_manager_identifier of this EmManagedExternalExadataInsightSummary.
        :type: str
        """
        self._enterprise_manager_identifier = enterprise_manager_identifier

    @property
    def enterprise_manager_entity_name(self):
        """
        **[Required]** Gets the enterprise_manager_entity_name of this EmManagedExternalExadataInsightSummary.
        Enterprise Manager Entity Name


        :return: The enterprise_manager_entity_name of this EmManagedExternalExadataInsightSummary.
        :rtype: str
        """
        return self._enterprise_manager_entity_name

    @enterprise_manager_entity_name.setter
    def enterprise_manager_entity_name(self, enterprise_manager_entity_name):
        """
        Sets the enterprise_manager_entity_name of this EmManagedExternalExadataInsightSummary.
        Enterprise Manager Entity Name


        :param enterprise_manager_entity_name: The enterprise_manager_entity_name of this EmManagedExternalExadataInsightSummary.
        :type: str
        """
        self._enterprise_manager_entity_name = enterprise_manager_entity_name

    @property
    def enterprise_manager_entity_type(self):
        """
        **[Required]** Gets the enterprise_manager_entity_type of this EmManagedExternalExadataInsightSummary.
        Enterprise Manager Entity Type


        :return: The enterprise_manager_entity_type of this EmManagedExternalExadataInsightSummary.
        :rtype: str
        """
        return self._enterprise_manager_entity_type

    @enterprise_manager_entity_type.setter
    def enterprise_manager_entity_type(self, enterprise_manager_entity_type):
        """
        Sets the enterprise_manager_entity_type of this EmManagedExternalExadataInsightSummary.
        Enterprise Manager Entity Type


        :param enterprise_manager_entity_type: The enterprise_manager_entity_type of this EmManagedExternalExadataInsightSummary.
        :type: str
        """
        self._enterprise_manager_entity_type = enterprise_manager_entity_type

    @property
    def enterprise_manager_entity_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_entity_identifier of this EmManagedExternalExadataInsightSummary.
        Enterprise Manager Entity Unique Identifier


        :return: The enterprise_manager_entity_identifier of this EmManagedExternalExadataInsightSummary.
        :rtype: str
        """
        return self._enterprise_manager_entity_identifier

    @enterprise_manager_entity_identifier.setter
    def enterprise_manager_entity_identifier(self, enterprise_manager_entity_identifier):
        """
        Sets the enterprise_manager_entity_identifier of this EmManagedExternalExadataInsightSummary.
        Enterprise Manager Entity Unique Identifier


        :param enterprise_manager_entity_identifier: The enterprise_manager_entity_identifier of this EmManagedExternalExadataInsightSummary.
        :type: str
        """
        self._enterprise_manager_entity_identifier = enterprise_manager_entity_identifier

    @property
    def enterprise_manager_entity_display_name(self):
        """
        Gets the enterprise_manager_entity_display_name of this EmManagedExternalExadataInsightSummary.
        Enterprise Manager Entity Display Name


        :return: The enterprise_manager_entity_display_name of this EmManagedExternalExadataInsightSummary.
        :rtype: str
        """
        return self._enterprise_manager_entity_display_name

    @enterprise_manager_entity_display_name.setter
    def enterprise_manager_entity_display_name(self, enterprise_manager_entity_display_name):
        """
        Sets the enterprise_manager_entity_display_name of this EmManagedExternalExadataInsightSummary.
        Enterprise Manager Entity Display Name


        :param enterprise_manager_entity_display_name: The enterprise_manager_entity_display_name of this EmManagedExternalExadataInsightSummary.
        :type: str
        """
        self._enterprise_manager_entity_display_name = enterprise_manager_entity_display_name

    @property
    def enterprise_manager_bridge_id(self):
        """
        **[Required]** Gets the enterprise_manager_bridge_id of this EmManagedExternalExadataInsightSummary.
        OPSI Enterprise Manager Bridge OCID


        :return: The enterprise_manager_bridge_id of this EmManagedExternalExadataInsightSummary.
        :rtype: str
        """
        return self._enterprise_manager_bridge_id

    @enterprise_manager_bridge_id.setter
    def enterprise_manager_bridge_id(self, enterprise_manager_bridge_id):
        """
        Sets the enterprise_manager_bridge_id of this EmManagedExternalExadataInsightSummary.
        OPSI Enterprise Manager Bridge OCID


        :param enterprise_manager_bridge_id: The enterprise_manager_bridge_id of this EmManagedExternalExadataInsightSummary.
        :type: str
        """
        self._enterprise_manager_bridge_id = enterprise_manager_bridge_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Promotion(object):
    """
    Promotion information for a subscription.
    """

    #: A constant which can be used with the status property of a Promotion.
    #: This constant has a value of "INITIALIZED"
    STATUS_INITIALIZED = "INITIALIZED"

    #: A constant which can be used with the status property of a Promotion.
    #: This constant has a value of "ACTIVE"
    STATUS_ACTIVE = "ACTIVE"

    #: A constant which can be used with the status property of a Promotion.
    #: This constant has a value of "EXPIRED"
    STATUS_EXPIRED = "EXPIRED"

    def __init__(self, **kwargs):
        """
        Initializes a new Promotion object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param duration:
            The value to assign to the duration property of this Promotion.
        :type duration: int

        :param duration_unit:
            The value to assign to the duration_unit property of this Promotion.
        :type duration_unit: str

        :param amount:
            The value to assign to the amount property of this Promotion.
        :type amount: float

        :param status:
            The value to assign to the status property of this Promotion.
            Allowed values for this property are: "INITIALIZED", "ACTIVE", "EXPIRED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param is_intent_to_pay:
            The value to assign to the is_intent_to_pay property of this Promotion.
        :type is_intent_to_pay: bool

        :param currency_unit:
            The value to assign to the currency_unit property of this Promotion.
        :type currency_unit: str

        :param time_started:
            The value to assign to the time_started property of this Promotion.
        :type time_started: datetime

        :param time_expired:
            The value to assign to the time_expired property of this Promotion.
        :type time_expired: datetime

        """
        self.swagger_types = {
            'duration': 'int',
            'duration_unit': 'str',
            'amount': 'float',
            'status': 'str',
            'is_intent_to_pay': 'bool',
            'currency_unit': 'str',
            'time_started': 'datetime',
            'time_expired': 'datetime'
        }

        self.attribute_map = {
            'duration': 'duration',
            'duration_unit': 'durationUnit',
            'amount': 'amount',
            'status': 'status',
            'is_intent_to_pay': 'isIntentToPay',
            'currency_unit': 'currencyUnit',
            'time_started': 'timeStarted',
            'time_expired': 'timeExpired'
        }

        self._duration = None
        self._duration_unit = None
        self._amount = None
        self._status = None
        self._is_intent_to_pay = None
        self._currency_unit = None
        self._time_started = None
        self._time_expired = None

    @property
    def duration(self):
        """
        Gets the duration of this Promotion.
        How long the promotion related to the subscription, if any, is valid in duration units.


        :return: The duration of this Promotion.
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """
        Sets the duration of this Promotion.
        How long the promotion related to the subscription, if any, is valid in duration units.


        :param duration: The duration of this Promotion.
        :type: int
        """
        self._duration = duration

    @property
    def duration_unit(self):
        """
        Gets the duration_unit of this Promotion.
        Unit for the duration.


        :return: The duration_unit of this Promotion.
        :rtype: str
        """
        return self._duration_unit

    @duration_unit.setter
    def duration_unit(self, duration_unit):
        """
        Sets the duration_unit of this Promotion.
        Unit for the duration.


        :param duration_unit: The duration_unit of this Promotion.
        :type: str
        """
        self._duration_unit = duration_unit

    @property
    def amount(self):
        """
        Gets the amount of this Promotion.
        Total amount of credit for the promotion related to the subscription if there is one.


        :return: The amount of this Promotion.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this Promotion.
        Total amount of credit for the promotion related to the subscription if there is one.


        :param amount: The amount of this Promotion.
        :type: float
        """
        self._amount = amount

    @property
    def status(self):
        """
        Gets the status of this Promotion.
        Current status of the promotion related to the subscription if there is one.

        Allowed values for this property are: "INITIALIZED", "ACTIVE", "EXPIRED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this Promotion.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Promotion.
        Current status of the promotion related to the subscription if there is one.


        :param status: The status of this Promotion.
        :type: str
        """
        allowed_values = ["INITIALIZED", "ACTIVE", "EXPIRED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def is_intent_to_pay(self):
        """
        Gets the is_intent_to_pay of this Promotion.
        Whether or not customer intends to pay once the promotion is done.


        :return: The is_intent_to_pay of this Promotion.
        :rtype: bool
        """
        return self._is_intent_to_pay

    @is_intent_to_pay.setter
    def is_intent_to_pay(self, is_intent_to_pay):
        """
        Sets the is_intent_to_pay of this Promotion.
        Whether or not customer intends to pay once the promotion is done.


        :param is_intent_to_pay: The is_intent_to_pay of this Promotion.
        :type: bool
        """
        self._is_intent_to_pay = is_intent_to_pay

    @property
    def currency_unit(self):
        """
        Gets the currency_unit of this Promotion.
        Currency unit associated with the promotion.


        :return: The currency_unit of this Promotion.
        :rtype: str
        """
        return self._currency_unit

    @currency_unit.setter
    def currency_unit(self, currency_unit):
        """
        Sets the currency_unit of this Promotion.
        Currency unit associated with the promotion.


        :param currency_unit: The currency_unit of this Promotion.
        :type: str
        """
        self._currency_unit = currency_unit

    @property
    def time_started(self):
        """
        Gets the time_started of this Promotion.
        Date-time for when the promotion starts.


        :return: The time_started of this Promotion.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this Promotion.
        Date-time for when the promotion starts.


        :param time_started: The time_started of this Promotion.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_expired(self):
        """
        Gets the time_expired of this Promotion.
        Date-time for when the promotion ends.


        :return: The time_expired of this Promotion.
        :rtype: datetime
        """
        return self._time_expired

    @time_expired.setter
    def time_expired(self, time_expired):
        """
        Sets the time_expired of this Promotion.
        Date-time for when the promotion ends.


        :param time_expired: The time_expired of this Promotion.
        :type: datetime
        """
        self._time_expired = time_expired

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IngressGatewayRouteTable(object):
    """
    This resource represents a customer-managed ingress gateway route table in the Service Mesh.
    """

    #: A constant which can be used with the lifecycle_state property of a IngressGatewayRouteTable.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a IngressGatewayRouteTable.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a IngressGatewayRouteTable.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a IngressGatewayRouteTable.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a IngressGatewayRouteTable.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a IngressGatewayRouteTable.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new IngressGatewayRouteTable object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this IngressGatewayRouteTable.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this IngressGatewayRouteTable.
        :type compartment_id: str

        :param ingress_gateway_id:
            The value to assign to the ingress_gateway_id property of this IngressGatewayRouteTable.
        :type ingress_gateway_id: str

        :param name:
            The value to assign to the name property of this IngressGatewayRouteTable.
        :type name: str

        :param description:
            The value to assign to the description property of this IngressGatewayRouteTable.
        :type description: str

        :param priority:
            The value to assign to the priority property of this IngressGatewayRouteTable.
        :type priority: int

        :param route_rules:
            The value to assign to the route_rules property of this IngressGatewayRouteTable.
        :type route_rules: list[oci.service_mesh.models.IngressGatewayTrafficRouteRule]

        :param time_created:
            The value to assign to the time_created property of this IngressGatewayRouteTable.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this IngressGatewayRouteTable.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this IngressGatewayRouteTable.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this IngressGatewayRouteTable.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this IngressGatewayRouteTable.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this IngressGatewayRouteTable.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this IngressGatewayRouteTable.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'ingress_gateway_id': 'str',
            'name': 'str',
            'description': 'str',
            'priority': 'int',
            'route_rules': 'list[IngressGatewayTrafficRouteRule]',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'ingress_gateway_id': 'ingressGatewayId',
            'name': 'name',
            'description': 'description',
            'priority': 'priority',
            'route_rules': 'routeRules',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._compartment_id = None
        self._ingress_gateway_id = None
        self._name = None
        self._description = None
        self._priority = None
        self._route_rules = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this IngressGatewayRouteTable.
        Unique identifier that is immutable on creation.


        :return: The id of this IngressGatewayRouteTable.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IngressGatewayRouteTable.
        Unique identifier that is immutable on creation.


        :param id: The id of this IngressGatewayRouteTable.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this IngressGatewayRouteTable.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this IngressGatewayRouteTable.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this IngressGatewayRouteTable.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this IngressGatewayRouteTable.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def ingress_gateway_id(self):
        """
        **[Required]** Gets the ingress_gateway_id of this IngressGatewayRouteTable.
        The OCID of the ingress gateway.


        :return: The ingress_gateway_id of this IngressGatewayRouteTable.
        :rtype: str
        """
        return self._ingress_gateway_id

    @ingress_gateway_id.setter
    def ingress_gateway_id(self, ingress_gateway_id):
        """
        Sets the ingress_gateway_id of this IngressGatewayRouteTable.
        The OCID of the ingress gateway.


        :param ingress_gateway_id: The ingress_gateway_id of this IngressGatewayRouteTable.
        :type: str
        """
        self._ingress_gateway_id = ingress_gateway_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this IngressGatewayRouteTable.
        A user-friendly name. The name must be unique within the same ingress gateway and cannot be changed after creation.
        Avoid entering confidential information.

        Example: `My unique resource name`


        :return: The name of this IngressGatewayRouteTable.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this IngressGatewayRouteTable.
        A user-friendly name. The name must be unique within the same ingress gateway and cannot be changed after creation.
        Avoid entering confidential information.

        Example: `My unique resource name`


        :param name: The name of this IngressGatewayRouteTable.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this IngressGatewayRouteTable.
        Description of the resource. It can be changed after creation.
        Avoid entering confidential information.

        Example: `This is my new resource`


        :return: The description of this IngressGatewayRouteTable.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this IngressGatewayRouteTable.
        Description of the resource. It can be changed after creation.
        Avoid entering confidential information.

        Example: `This is my new resource`


        :param description: The description of this IngressGatewayRouteTable.
        :type: str
        """
        self._description = description

    @property
    def priority(self):
        """
        Gets the priority of this IngressGatewayRouteTable.
        The priority of the route table. A lower value means a higher priority. The routes are declared based on the priority.


        :return: The priority of this IngressGatewayRouteTable.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this IngressGatewayRouteTable.
        The priority of the route table. A lower value means a higher priority. The routes are declared based on the priority.


        :param priority: The priority of this IngressGatewayRouteTable.
        :type: int
        """
        self._priority = priority

    @property
    def route_rules(self):
        """
        **[Required]** Gets the route_rules of this IngressGatewayRouteTable.
        The route rules for the ingress gateway.


        :return: The route_rules of this IngressGatewayRouteTable.
        :rtype: list[oci.service_mesh.models.IngressGatewayTrafficRouteRule]
        """
        return self._route_rules

    @route_rules.setter
    def route_rules(self, route_rules):
        """
        Sets the route_rules of this IngressGatewayRouteTable.
        The route rules for the ingress gateway.


        :param route_rules: The route_rules of this IngressGatewayRouteTable.
        :type: list[oci.service_mesh.models.IngressGatewayTrafficRouteRule]
        """
        self._route_rules = route_rules

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this IngressGatewayRouteTable.
        The time when this resource was created in an RFC3339 formatted datetime string.


        :return: The time_created of this IngressGatewayRouteTable.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this IngressGatewayRouteTable.
        The time when this resource was created in an RFC3339 formatted datetime string.


        :param time_created: The time_created of this IngressGatewayRouteTable.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this IngressGatewayRouteTable.
        The time when this resource was updated in an RFC3339 formatted datetime string.


        :return: The time_updated of this IngressGatewayRouteTable.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this IngressGatewayRouteTable.
        The time when this resource was updated in an RFC3339 formatted datetime string.


        :param time_updated: The time_updated of this IngressGatewayRouteTable.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this IngressGatewayRouteTable.
        The current state of the Resource.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this IngressGatewayRouteTable.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this IngressGatewayRouteTable.
        The current state of the Resource.


        :param lifecycle_state: The lifecycle_state of this IngressGatewayRouteTable.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this IngressGatewayRouteTable.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.


        :return: The lifecycle_details of this IngressGatewayRouteTable.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this IngressGatewayRouteTable.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.


        :param lifecycle_details: The lifecycle_details of this IngressGatewayRouteTable.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this IngressGatewayRouteTable.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this IngressGatewayRouteTable.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this IngressGatewayRouteTable.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this IngressGatewayRouteTable.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this IngressGatewayRouteTable.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this IngressGatewayRouteTable.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this IngressGatewayRouteTable.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this IngressGatewayRouteTable.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this IngressGatewayRouteTable.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this IngressGatewayRouteTable.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this IngressGatewayRouteTable.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this IngressGatewayRouteTable.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AuthenticationProviderSummary(object):
    """
    Summary of the Authentication Provider.
    """

    #: A constant which can be used with the grant_type property of a AuthenticationProviderSummary.
    #: This constant has a value of "CLIENT_CREDENTIALS"
    GRANT_TYPE_CLIENT_CREDENTIALS = "CLIENT_CREDENTIALS"

    #: A constant which can be used with the grant_type property of a AuthenticationProviderSummary.
    #: This constant has a value of "AUTHORIZATION_CODE"
    GRANT_TYPE_AUTHORIZATION_CODE = "AUTHORIZATION_CODE"

    #: A constant which can be used with the identity_provider property of a AuthenticationProviderSummary.
    #: This constant has a value of "GENERIC"
    IDENTITY_PROVIDER_GENERIC = "GENERIC"

    #: A constant which can be used with the identity_provider property of a AuthenticationProviderSummary.
    #: This constant has a value of "OAM"
    IDENTITY_PROVIDER_OAM = "OAM"

    #: A constant which can be used with the identity_provider property of a AuthenticationProviderSummary.
    #: This constant has a value of "GOOGLE"
    IDENTITY_PROVIDER_GOOGLE = "GOOGLE"

    #: A constant which can be used with the identity_provider property of a AuthenticationProviderSummary.
    #: This constant has a value of "MICROSOFT"
    IDENTITY_PROVIDER_MICROSOFT = "MICROSOFT"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProviderSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProviderSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProviderSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProviderSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProviderSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProviderSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a AuthenticationProviderSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new AuthenticationProviderSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AuthenticationProviderSummary.
        :type id: str

        :param grant_type:
            The value to assign to the grant_type property of this AuthenticationProviderSummary.
            Allowed values for this property are: "CLIENT_CREDENTIALS", "AUTHORIZATION_CODE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type grant_type: str

        :param identity_provider:
            The value to assign to the identity_provider property of this AuthenticationProviderSummary.
            Allowed values for this property are: "GENERIC", "OAM", "GOOGLE", "MICROSOFT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type identity_provider: str

        :param name:
            The value to assign to the name property of this AuthenticationProviderSummary.
        :type name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AuthenticationProviderSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this AuthenticationProviderSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this AuthenticationProviderSummary.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this AuthenticationProviderSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this AuthenticationProviderSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'grant_type': 'str',
            'identity_provider': 'str',
            'name': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'grant_type': 'grantType',
            'identity_provider': 'identityProvider',
            'name': 'name',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._grant_type = None
        self._identity_provider = None
        self._name = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AuthenticationProviderSummary.
        Unique immutable identifier that was assigned when the Authentication Provider was created.


        :return: The id of this AuthenticationProviderSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AuthenticationProviderSummary.
        Unique immutable identifier that was assigned when the Authentication Provider was created.


        :param id: The id of this AuthenticationProviderSummary.
        :type: str
        """
        self._id = id

    @property
    def grant_type(self):
        """
        **[Required]** Gets the grant_type of this AuthenticationProviderSummary.
        The grant type for the Authentication Provider.

        Allowed values for this property are: "CLIENT_CREDENTIALS", "AUTHORIZATION_CODE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The grant_type of this AuthenticationProviderSummary.
        :rtype: str
        """
        return self._grant_type

    @grant_type.setter
    def grant_type(self, grant_type):
        """
        Sets the grant_type of this AuthenticationProviderSummary.
        The grant type for the Authentication Provider.


        :param grant_type: The grant_type of this AuthenticationProviderSummary.
        :type: str
        """
        allowed_values = ["CLIENT_CREDENTIALS", "AUTHORIZATION_CODE"]
        if not value_allowed_none_or_none_sentinel(grant_type, allowed_values):
            grant_type = 'UNKNOWN_ENUM_VALUE'
        self._grant_type = grant_type

    @property
    def identity_provider(self):
        """
        **[Required]** Gets the identity_provider of this AuthenticationProviderSummary.
        Which type of Identity Provider (IDP) you are using.

        Allowed values for this property are: "GENERIC", "OAM", "GOOGLE", "MICROSOFT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The identity_provider of this AuthenticationProviderSummary.
        :rtype: str
        """
        return self._identity_provider

    @identity_provider.setter
    def identity_provider(self, identity_provider):
        """
        Sets the identity_provider of this AuthenticationProviderSummary.
        Which type of Identity Provider (IDP) you are using.


        :param identity_provider: The identity_provider of this AuthenticationProviderSummary.
        :type: str
        """
        allowed_values = ["GENERIC", "OAM", "GOOGLE", "MICROSOFT"]
        if not value_allowed_none_or_none_sentinel(identity_provider, allowed_values):
            identity_provider = 'UNKNOWN_ENUM_VALUE'
        self._identity_provider = identity_provider

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AuthenticationProviderSummary.
        A name to identify the Authentication Provider.


        :return: The name of this AuthenticationProviderSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AuthenticationProviderSummary.
        A name to identify the Authentication Provider.


        :param name: The name of this AuthenticationProviderSummary.
        :type: str
        """
        self._name = name

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this AuthenticationProviderSummary.
        The Authentication Provider's current state.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AuthenticationProviderSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AuthenticationProviderSummary.
        The Authentication Provider's current state.


        :param lifecycle_state: The lifecycle_state of this AuthenticationProviderSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this AuthenticationProviderSummary.
        When the resource was created. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this AuthenticationProviderSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AuthenticationProviderSummary.
        When the resource was created. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this AuthenticationProviderSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this AuthenticationProviderSummary.
        When the resource was last updated. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_updated of this AuthenticationProviderSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this AuthenticationProviderSummary.
        When the resource was last updated. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_updated: The time_updated of this AuthenticationProviderSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this AuthenticationProviderSummary.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this AuthenticationProviderSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this AuthenticationProviderSummary.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this AuthenticationProviderSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this AuthenticationProviderSummary.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this AuthenticationProviderSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this AuthenticationProviderSummary.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this AuthenticationProviderSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SubscriptionCurrency(object):
    """
    Currency details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SubscriptionCurrency object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this SubscriptionCurrency.
        :type name: str

        :param iso_code:
            The value to assign to the iso_code property of this SubscriptionCurrency.
        :type iso_code: str

        :param std_precision:
            The value to assign to the std_precision property of this SubscriptionCurrency.
        :type std_precision: int

        """
        self.swagger_types = {
            'name': 'str',
            'iso_code': 'str',
            'std_precision': 'int'
        }

        self.attribute_map = {
            'name': 'name',
            'iso_code': 'isoCode',
            'std_precision': 'stdPrecision'
        }

        self._name = None
        self._iso_code = None
        self._std_precision = None

    @property
    def name(self):
        """
        Gets the name of this SubscriptionCurrency.
        Currency name


        :return: The name of this SubscriptionCurrency.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SubscriptionCurrency.
        Currency name


        :param name: The name of this SubscriptionCurrency.
        :type: str
        """
        self._name = name

    @property
    def iso_code(self):
        """
        **[Required]** Gets the iso_code of this SubscriptionCurrency.
        Currency Code


        :return: The iso_code of this SubscriptionCurrency.
        :rtype: str
        """
        return self._iso_code

    @iso_code.setter
    def iso_code(self, iso_code):
        """
        Sets the iso_code of this SubscriptionCurrency.
        Currency Code


        :param iso_code: The iso_code of this SubscriptionCurrency.
        :type: str
        """
        self._iso_code = iso_code

    @property
    def std_precision(self):
        """
        Gets the std_precision of this SubscriptionCurrency.
        Standard Precision of the Currency


        :return: The std_precision of this SubscriptionCurrency.
        :rtype: int
        """
        return self._std_precision

    @std_precision.setter
    def std_precision(self, std_precision):
        """
        Sets the std_precision of this SubscriptionCurrency.
        Standard Precision of the Currency


        :param std_precision: The std_precision of this SubscriptionCurrency.
        :type: int
        """
        self._std_precision = std_precision

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
